@@ -113,6 +113,9 @@ def _clean_bag_api_output(api_output: dict) -> List[dict]:
             elif value is None:
                 new_dict[key] = ""
 
+        # Add "toevoeging" to the dictionary
+        new_dict["toevoeging"] = f"{new_dict['huisletter']}{new_dict['huisnummertoevoeging']}".strip()
+
         # Add the new dictionary to the list
         adressen.append(new_dict)
 
@@ -132,6 +135,7 @@ def get_zip_code_info(
         - huisnummer
         - huisletter
         - huisnummertoevoeging
+        - toevoeging
         - woonplaats
         - bouwjaar
         - oppervlakte
